@@ -1,4 +1,4 @@
-from .CTE import DAG_FP, INPUT_FP, MF_FP, OUTPUT_FP
+from .CTE import DAG_FP, INPUT_FP, MF_FP, OUTPUT_FP, SNAKEMAKE_EXIT_CODE_FP
 from .debug import debug_print, filtered_environment
 from .error import handle_unknown_exception
 from .image import default_rule_parameters, get_tools
